#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.21
%define baseversionminus1 1.20

Name:           kubernetes%{baseversion}
Version:        1.21.14
Release:        2.4
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go-go-md2man
# Kubernetes 1.21.4 requires at least go 1.16.7 (see changelog)
BuildRequires:  go >= 1.16.7
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.16
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.











# packages to build containerized control plane

%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes-client-common >= %{version}
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Obsoletes:      kubernetes%{baseversionminus1}-client-common

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion

%description client-bash-completion
Bash command line completion support for %{name}-client

%description client-common
Kubernetes client tools common files

%prep
%setup -q -n kubernetes-%{version}
%patch2 -p0
%patch3 -p1
%patch4 -p0
%patch5 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
%ifarch ppc64le
export GOLDFLAGS='-linkmode=external'
%endif

#TEST
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
%service_add_post kubelet.service
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%changelog
* Mon Mar 27 2023 Robert Munteanu <rombert@apache.org>
- Stronger conflicts for completion packages
* Mon Mar 27 2023 Robert Munteanu <rombert@apache.org>
- Split individual completions into separate packages
* Thu Mar  2 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.21.14:
  * Release commit for Kubernetes v1.21.14
  * Reject proxy requests to 0.0.0.0 as well
  * etcd-client starts retrying transient errors from the etcd cluster
  * authn: fix cache mutation by AuthenticatedGroupAdder
  * Fix OpenAPI loading error caused by empty APIService
  * Correct event registration for multiple scheduler plugins.
  * Fix: abort nominating a pod that was already scheduled to a node
  * cpu manager policy set to none, no one remove container id from container map, lead memory leak
  * kube-up: use registry.k8s.io for containerd-related jobs
  * Skip updating Endpoints and EndpointSlice if no relevant fields change
  * ipvs: remove port opener
  * iptables: remove port opener
  * Extract containerID from systemd-style cgroupPath in cri_stats_provider And fix test to generate UUID without dash
  * update go.mod for golang.org/x/crypto to v0.0.0-20211202192323-5770296d904e
  * azure_file: try to get secret namespace from ClaimRef
  * azure_file: add namespace tests for InTree to CSI conversion
  * Update Go to 1.16.15
  * cluster/gce: update konnectivity image tags to v0.0.30
  * bump sigs.k8s.io/apiserver-network-proxy/konnectivity-client@v0.0.30
  * fix dryrun when ca file exists
  * fix regression introduced by PR 100320
  * bump k8s.io/utils for inotify fix
  * cronjob_controllerv2: do not filter jobs to be reconciled by labels
  * fix: remove outdated ipv4 route when the corresponding node is deleted
  * Updating EndpointSlice strategy to retain node name in topology until field is set
  * Add PDB selector patch integration test
  * Revert v1beta1 PodDisruptionBudget select patchStrategy
  * kubeadm: fix the bug that 'kubeadm init --dry-run --upload-certs' command failed with 'secret not found' error
  * Mark device as uncertain if unmount device succeeds
  * add namespace in azurefile volumeid
  * fix: azurefile volumeid conflict in csi migration
  * Fix DaemonSet status update retry
  * Enabling kube-proxy metrics on windows kernel mode
  * fix: delete non existing disk issue
  * fix containers order after applying
  * upgrade sigs.k8s.io/structured-merge-diff/v4 to v4.2.1
  * fix: do not delete the lb that does not exist
  * Fix header mutation race in timeout filter
  * Don't set sysctl net.ipv4.vs.conn_reuse_mode for kernels >=5.9
  * kubeadm: remove the restriction that the ca.crt can only contain one certificate
  * flake fix: remove the error handler for cronjob integration test
  * vendor: bump cAdvisor to v0.39.3
  * Fix the leak of vSphere client sessions
  * client-go: Clear the ResourceVersionMatch on paged list calls
  * Update GCE manifest to use konnectivity v0.0.27
  * Update to apiserver-network-proxy v0.0.27
  * Improving performance of EndpointSlice controller metrics cache
  * Mark volume mount as uncertain in case of volume expansion fails
  * mount-utils: Detect potential stale file handle
  * Add GetPossiblyMountedVolumesForPod to let kubelet know all volumes were unmounted
  * Add e2e test for NodeUnstage error cases
  * Skip creating HNS loadbalancer with empty endpoints
  * dependencies: Update golang.org/x/net to v0.0.0-20211209124913-491a49abca63
  * kubeadm: avoid requiring a CA key during kubeconfig expiration checks
  * kubeadm: print the CA of kubeconfig files in "check expiration"
  * kubeadm: validate local etcd certficates during expiration checks
  * publishing-bot/rules: drop rules for release-1.17 branch
  * Ensure deletion of pods in queues and cache
  * kube-scheduler: Increase the duration to expire an assumed pod
  * Skip check for all topology labels when using system default spreading
  * workqueue: fix leak in queue preventing objects from being GCed
  * Update mounter interface in volume manager
  * Ignore 'wait: no child processes' error when calling mount/umount
  * Reduce calls to docker from dockershim for stats
  * Fix concurrent map writes error in kube-apiserver
  * e2e: node: release-1.21: backport findKubeletServiceName
  * node: e2e: add test for the checkpoint recovery
  * devicemanager: checkpoint: support pre-1.20 data
  * fix: remove VMSS and VMSS instances from SLB backend pool only when necessary
  * fix: leave the probe path empty for TCP probes
  * fix: skip instance not found when decoupling vmss from lb
  * Add test for counting inodes correct with hardlinks
  * Get inodes and disk usage via pure go
* Mon Feb  7 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism in client-common postinstall script (bsc#1195391)
* Wed Dec  8 2021 rbrown@suse.com
- Update to version 1.21.7:
  * parameter 'disabled-metrics' is invalid
  * defer close the rotated log open
  * Fixed nil pointer dereference
  * Add tests for checking bind mounts
  * Check subpath file
  * Add check for subpaths
  * Manual cherry pick of kube-openapi changes for release-1.21 Bump kube-openapi against kube-openapi/release-1.21 branch
  * Fixed unit test SELinux support
  * Add shortcut for SELinux detection
  * Don't guess SELinux support on error
  * Use separate pathSpec for local and remote to properly handle cleaning paths
  * [go1.16] Update to go1.16.10
  * Automated cherry pick of #105122: added keys for structured logging (#105138)
  * Update debian, debian-iptables, setcap images to pick up CVEs fixes
  * Fixing how EndpointSlice Mirroring handles Service selector transitions
  * Fix race condition in logging when request times out
  * Remove nodes with Cluster Autoscaler taint from LB backends.
  * Retry detaching FibreChannel volume few times
  * Regenerate vendor/
  * Move error reporting to volume plugins
  * Retry reading /proc/mounts indifinetly in FC and iSCSI volume reconstruction
  * ConsistentRead tries 10 times
  * Bump k8s.io/utils
  * Fix issue in node status updating VolumeAttached list
  * Support cgroupv2 in node problem detector test
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.6
  * Fix log spam for du failure on pod etc-hosts metrics
  * Run storage hostpath e2e test client pod as privileged
  * support more than 100 disk mounts on Windows
  * Update to go1.16.9
  * Fix PreferNominatedNode test
  * Verifying the auth headers are set for upgraded aggregated API requests
  * apiserver aggregator upgrade unit test
  * Aggregator uses the regular transport even if the request requires upgrades
  * check log directory for restartCount
  * Copy VolumeSnapshotContent annotations in snapshottable.go test
  * Bump klog to v2.9.0
  * Ignore VMs in vmss delete backend pools
  * aggregate errors when putting vmss
  * fix: skip not found nodes when reconciling LB backend address pools
  * fix: consolidate logs for instance not found error
  * Remove a duplicate StorageClass creation call
  * Bump golang.org/x/text to v0.3.6
  * Revert 102925: Fix Node Resources plugins score when there are pods with no requests
  * e2e scheduling priorities: do not reference control loop variable
  * storege e2etest: Delete restored PVC/Pod in snapshottable
  * tests: Wait for the network connectivity first
  * v1.21: Fix test flake in old svc registry
  * 'New' Event namespace validate failed
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.5
  * Refine locking in API Priority and Fairness config controller
  * kube-controller-manager: properly check generic ephemeral volume feature
  * Fix null JSON round tripping
  * Propagate conversion errors
  * integration test
  * fix 104329: check for headless before trying to release the ClusterIPs
  * fix detach disk issue on deleting node
  * fix: ignore the case when comparing azure tags in service annotation
  * fix: ignore the case when updating tags
  * backport metrics grabbing through port-forwarding
  * remove listx from OWNERS_ALIASES
  * Only use dualstack if the node and config supports it
  * Local PV e2e: fix leaked local volumes
  * Add explicit capability for online volume expansion
* Wed Oct  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Bump disk requirements in _constraints to 12GB. Data based on the
  last successful build consumed storage.
* Thu Sep 16 2021 rbrown@suse.com
- Update to version 1.21.5:
  * Update to go1.16.8
  * legacy-cloud-providers: aws: Add support for consuming web identity credentials
  * e2e iperf2 change threshold to 10MBps = 80 Mbps
  * Fix NodeAuthenticator tests in dual stack
  * Fix the key missing issue for structured log
  * Fix a small regression in Service updates
  * Service: Fix semantics for Update wrt allocations
  * Don't prematurely close reflectors in case of slow initialization in watch based manager
  * Fix storage class setup in regional_pd.go
  * backport 104410 to release-1.21
  * pkg/kubelet/cm: use SkipFreezeOnSet
  * vendor: bump runc to 1.0.2
  * Switch to non-deprecated timestamppb.Now()
  * Fix buckets initialization
  * fix: ensure InstanceShutdownByProviderID return false for creating Azure VMs
  * fix: skip case sensitivity when checking Azure NSG rules
  * Keep MakeMountArgSensitive and add a new signature that receives flags
  * Update the unit tests to handle mountFlags
  * Add missing interface method in mount_unsupported.go
  * Pass additional flags to subpath mount to avoid flakes in certain conditions
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.4
  * Copy golang license to staging copies
  * delete stale UDP conntrack entries for loadbalancer IPs
  * Set idle and readheader timeouts
* Wed Aug 25 2021 rbrown@suse.com
- Update to version 1.21.4:
  * Avoid spurious calls to update/delete validation
  * Update to go1.16.7
  * Fix metrics reporting for the deprecated watch path
  * Update configure-helper.sh
  * Update configure-helper.sh
  * Update configure-helper.sh
  * Fix disruptive subPath test failures
  * Fix: ignore not a VMSS error for VMAS nodes in reconcileBackendPools
  * feat: Provide IPv6 support for internal load balancer
  * Update to using apiserver-network-proxy v1.22
  * Make CSR cleaner tolerate objects with invalid status.certificate
  * disable aufs module
  * Update pd csi driver images to use v1 images (CSINode, CSIDriver, etc)
  * storage e2e: patch in RBAC rules for secrets
  * storage e2e: downgrade hostpath driver
  * storage e2e: disable health check containers
  * storage e2e: automate hostpath YAML updates, hostpath v1.6.2
  * update comments and owners file for pkg/util/removeall
  * kubelet: do not call RemoveAll on volumes directory for orphaned pods
  * Fix panic in master upgrade tests
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.3
  * Updated to use konnectivity client v0.0.21, and implemented placeholder context
  * Fix the code is leaking the defaulting between unrelated pod instances
  * Simplify use of the fake dynamic client
  * fix: return empty VMAS name if using standalone VM
  * wait for endpoints to be available
  * Remove extra zone test
  * Fix frameworkImpl.extenders being not set
  * fix: Refresh VM cache when node is not found
  * fix: cleanup outdated routes
  * strip prefix 'v' in coredns version if exists
  * Fix closing of decorated watcher channel on timeout
  * fix: delete non existing disk issue
  * let objects without metadata pass through the managedFields admission controller
* Tue Jul 20 2021 Richard Brown <rbrown@suse.com>
- Introduce revert-coredns-image-renaming.patch to correct new
  upstream behaviour
* Mon Jul 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Drop kubeadm-opensuse-corednsimage.patch: fixed upstream.
* Fri Jul 16 2021 rbrown@suse.com
- Update to version 1.21.3:
  * move upgrade test frameworks closer to Describe
  * Update setcap image to buster-v2.0.3
  * Update debian-iptables image to buster-v1.6.5
  * Update debian-base image to buster-v1.8.0
  * Update to go1.16.6
  * Bump SMD to v4.1.2 to pick up #102749 fix
  * generate scheduler merge patches on the pod status instead of the full pod
  * Loadbalancer IngressIP policy should be configured as non-DSR to enable routing mesh by default
  * Fix race in attachdetach tests
  * Fix Node Resources plugins score when there are pods with no requests
  * Do not throw error when we can't get canonical path
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.2
  * Remove error wrap from logs
  * client-go: reduce log level of reflector again
  * Update to go1.16.5
  * feat: remove ephemeral-storage etcd requirement
  * endpointslicemirroring controller mirror address status
  * sched: fix a bug that a preemptor pod exists as a phantom
  * Revert "Cleanup portforward streams after their usage"
  * serviceOwnsFrontendIP shouldn't report error when the public IP doesn't match
  * Return UnschedulableAndUnresolvable when looking up volume-related resources returns NotFound error
  * Return UnschedulableAndUnresolvable instead of Error when failing to lookup pvc or storageclass in VolumeZone plugin
  * use subpath for coredns only for default repository
  * (scheduler e2e) Create balanced pods in parallel
  * Fix VolumeAttachment garbage collection for migrated PVs
  * fix error of setting negative value for containerLogMaxSize
  * Update setcap to buster-v2.0.1 and add setcap to dependencies.yaml
  * kubeadm: remove e2e test for ClusterStatus
  * Update etcd image revision
  * Update debian-base to buster-v1.7.0
  * Update debian-iptables to buster-v1.6.1
  * Upgrade konnectivity-client for GRPC connection fixes
  * Respect annotation size limit for SSA last-applied.
  * Remove unnecessary quotes from get-kube scripts
  * Fix expired unit test certs
  * Set cgroups via opencontainer
  * vendor: bump runc to rc95
  * pkg/kubelet/nodeshutdown/systemd: fix for dbus 5.0.4
  * kubelet: reuse manager
  * Azure: avoid setting cached Sku when updating VMSS and VMSS instances
  * Ref counting is only applicable to Remote endpoints
  * Make watch order conformance test reliable
  * Add missing clientset to EBS storage e2e test
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.1
  * fixed wrong warning in kube-proxy regarding topology aware hints
  * fix removing pods from podTopologyHints mapping
  * Update cos-gpu-installer image
  * fix: avoid nil-pointer panic when checking the frontend IP configuration
  * Add jitter to lease controller
  * Avoid caching the VMSS instances whose network profile is nil
  * fix: not tagging static public IP
  * Use CSI driver to determine unique name for migrated in-tree plugins
  * chunk target operatation for aws targetGroup
  * Fix watchForLockfileContention memory leak
* Tue May 25 2021 Richard Brown <rbrown@suse.com>
- Toggle ip4/ipv6 forwarding sysctls to ensure all devices are
  refreshed [boo#1186125]
* Thu May 20 2021 Richard Brown <rbrown@suse.com>
- Restore 90-kubeadm.conf, still needed [boo#1186125]
* Wed May 19 2021 Richard Brown <rbrown@suse.com>
- Stop setting sysctls on kubelet start with `sysctl -a --system`.
  Instead use more specific sysctl calls in kubelet service start.
  [boo#1186125]
* Wed May 19 2021 rbrown@suse.com
- Update to version 1.21.1:
  * [go1.16] Update to go1.16.4
  * Automated cherry pick of #101377: Fix validation in kubectl create ingress (#101426)
  * Update tests to use agnhost 2.32
  * Fix EndpointSlice describe panic when an Endpoint doesn't have zone
  * Add test create service with ns
  * Set namespace when using kubectl create service
  * Update pkg/volume/azure_file/azure_provision.go
  * Normalize share name to not include capital letters
  * Extend pod start timeout to 5min for storage subpath configmap test
  * Fix cleanupMountpoint issue for Windows
  * fix: set "host is down" as corrupted mount
  * no watch endpointslice in userpace mode
  * Ensure service deleted when the Azure resource group has been deleted
  * Update Makefile
  * Update dependencies.yaml
  * update debian-base to buster-v1.5.0 for CVEs
  * fix TestMutatingWebhookResetsInvalidManagedFields flakes
  * Updating EndpointSlice validation to match Endpoints validation
  * fix: azure file namespace issue in csi translation
  * pkg/kubelet: improve the node informer sync check
  * Remove Limits from scheduling e2e balanced pod resources
  * Additional CVE-2021-3121 fix
  * Fix RBAC of generic ephemeral volumes controller
  * move filesystem resize code to kubernetes/mount-utils and add need resize function
  * Fix panic when killing container fails
  * Fix startupProbe behaviour changed
  * Fix test
  * [go1.16] Update to go1.16.3
  * Fix Job describe for completion mode
  * Upgrade kustomize-in-kubectl to v4.1.2
  * exec test should not run in Parallel as feature gate is not locked
  * respect ExecProbeTimeout
  * apf: exempt probes /healthz /livez /readyz
  * DelegatingAuthenticationOptions TokenReview request timeout
  * add node handlers to the metaproxier
  * Updating Topology Aware Hints to support "Auto" value for annotation
  * list pod list once to avoid timeout
  * gce configure containerd default_runtime_name
  * Update the containerd runtime binary path - gce
  * Cleanup portforward streams after their usage
  * azure: fix node public IP not able to fetch issues from IMDS
  * Update CHANGELOG/CHANGELOG-1.21.md for v1.21.0
  * e2e test with hostNetwork pods can't run in parallel
  * do not tag user created public IPs
* Mon May 17 2021 Richard Brown <rbrown@suse.com>
- Revert remove workaround in 10-kubeadm.conf - still needed [boo#1186125]
* Wed May  5 2021 Anthony Rabbito <hello@anthonyrabbito.com>
- Remove workaround in 10-kubeadm.conf for boo#1171770 causing sysctl values to be reset
* Mon Apr 26 2021 Richard Brown <rbrown@suse.com>
- Introduce kubeadm-opensuse-corednsimage.patch to correct new
  coredns image name reference introduced in kubernetes 1.21
* Wed Apr 14 2021 Richard Brown <rbrown@suse.com>
- Rebase opensuse-version-checks.patch
* Tue Apr 13 2021 Richard Brown <rbrown@suse.com>
- Initial Package
